# phoenix_widgets

Phoenix Widgets is widget collections.

## Getting Started

In the `pubspec.yaml` of your flutter project, add the following dependency:

```yaml
dependencies:
  ...
  phoenix_widgets: "^latestVersion"
```

Import it:

```dart
import 'package:phoenix_widgets/phoenix_widgets.dart';
```

---
## PhoenixCard
PhoenixCard is widget to create card

![PhoenixCard](screenshots/phoenix_card.png)


### Usage Examples

```dart
 PhoenixCard(
    title: Text(
      "Title with Image",
      style: Theme.of(context).textTheme.headline6,
    ),
    description: Text(
      "Description",
      style: Theme.of(context).textTheme.bodyText2,
    ),
    footer: Row(
      mainAxisAlignment: MainAxisAlignment.start,
      children: [
        const CircleAvatar(backgroundColor: Colors.red),
        const SizedBox(width: 8),
        Text(
        "Footer",
        style: Theme.of(context).textTheme.headline6,
        )
      ],
    ),
    image: Image.network(
      "https://images.contentstack.io/v3/assets/blt2a130c768c36b9df/blt5f384c7eb51e7cff/5f7d972ddf178b0ea98488e1/banner_sadaqah.jpg?auto=webp",
      fit: BoxFit.cover,
    ),
    onTap: () {},
  ),

```
## Available Parameters 
| Param                       | Type         | isRequired |  Default          |
|-----------------------------|--------------|------------|------------       |
| image                       | Widget       | No         |                   |
| title                       | Widget       | Yes        |                   |
| description                 | Widget       | Yes        |                   |
| footer                      | Widget       | No         |                   |
| width                       | double       | No         | double.maxFinite  |
| padding                     | EdgeInsets   | No         |                   |
| margin                      | EdgeInsets   | No         | const EdgeInsets.symmetric(horizontal: 16,vertical: 8)|
| onTap                       | VoidCallback | No         |                   |
| backgroundColor             | Color        | No         | Colors.white      |
| borderRadius                | double       | No         | 4                 |
-------------------------------------------------------------------------------

---
## PhoenixBottomMenu
PhoenixBottomMenu is widget to create navigation bar 

![PhoenixCard](screenshots/phoenix_bottommenu.png)


### Usage Examples

```dart
PhoenixBottomMenu(
    navBarItems: [
      NavBarItem("Home", 'assets/tab_home.png'),
      NavBarItem("Profile", 'assets/tab_profile.png'),
      NavBarItem("Setting", 'assets/tab_setting.png'),
    ],
    selectedTabColor: Colors.red, ///optional
    unselectedTabColor: Colors.black54, ///optional
    onTabChange: (index) {
    setState(() {});
    _tabController!.jumpToPage(index);
    },
)

```
## Available Parameters
| Param                       | Type            | isRequired |  Default          |
|-----------------------------|-----------------|------------|------------       |
| navBarItems                 | List<NavBarItem>| Yes        |                   |
| selectedTabColor            | Color           | No         | Colors.red        |
| unselectedTabColor          | Color           | No         | Colors.black54    |
| onTabChange                 | Function        | Yes        |                   |
----------------------------------------------------------------------------------

---
